@@ -3,7 +3,7 @@
 
 """ Smart Automatic Cover Art Downloader : search and download music album covers. """
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 __author__ = "desbma"
 __license__ = "MPL 2.0"
 
@@ -34,10 +34,10 @@ import PIL.Image
 import PIL.ImageFile
 import requests
 
-import sacad.api_watcher
-import sacad.colored_logging
-import sacad.mkstemp_ctx
-import sacad.web_cache
+from . import api_watcher
+from . import colored_logging
+from . import mkstemp_ctx
+from . import web_cache
 
 
 USER_AGENT = "Mozilla/5.0"
@@ -207,7 +207,9 @@ class CoverSourceResult:
 
   def updateSignature(self):
     """ Calculate a cover's "signature" using its thumbnail url. """
-    assert(self.thumbnail_sig is None)
+    if self.thumbnail_sig is not None:
+      # TODO understand how it is possible to get here (only with Python 3.4 it seems)
+      return self
     if self.thumbnail_url is None:
       logging.getLogger().warning("No thumbnail available for %s" % (self))
       return
@@ -534,7 +536,7 @@ class CoverSource(metaclass=abc.ABCMeta):
         else:
           CoverSource.api_cache[url] = api_data
     except Exception as e:
-      #raise
+      # raise
       logging.getLogger().warning("Search with source '%s' failed: %s" % (self.__class__.__name__, e))
       return ()
 
@@ -612,9 +614,9 @@ class CoverSource(metaclass=abc.ABCMeta):
       self.updateHttpHeaders(headers)
       with self.api_watcher:
         if post_data is not None:
-          response = requests.post(url, data=post_data, headers=headers, timeout=5, verify=False)
+          response = requests.post(url, data=post_data, headers=headers, timeout=10, verify=False)
         else:
-          response = requests.get(url, headers=headers, timeout=5, verify=False)
+          response = requests.get(url, headers=headers, timeout=10, verify=False)
       response.raise_for_status()
       data = response.content
       # add cache entry only when parsing is successful
